(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12812,        459]*)
(*NotebookOutlinePosition[     14130,        499]*)
(*  CellTagsIndexPosition[     14086,        495]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{"\n", 
      StyleBox[\(HODGE\ STAR\ OPERATOR\),
        FontFamily->"Helvetica",
        FontSize->14,
        FontVariations->{"Underline"->True}]}]], "Input"],

Cell["\<\
(*An existing Kernel should be Quit to use this demonstration \
program, which can be stepped through manually, or executed all at once by \
Evaluate Initialization and then scrolled through.  Printing the notebook can \
serve as a reference for Hodge Star operations and syntax. Running time: ~ \
1/4 min.*)
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(<< AVF.m\)], "Input",
  InitializationCell->True],

Cell["\<\

(*ORTHONORMAL FRAMES AND HODGE STAR OPERATIONS*)\
\>", "Input",
  FormatType->TextForm],

Cell[TextData[{
  "(*A set of up to 6 basis forms (which may include a subset of the existing \
\"forms\") can be designated as an ",
  StyleBox["orthonormal",
    FontVariations->{"Underline"->True}],
  " frame by the command \"makeframe[list]\". The argument is just a list of \
form symbols, except that the symbol for any frame form with negative \
signature must be preceded by a minus sign.\n\nThe basis forms may be input \
in any order, but will be re-arranged into canonical order (and the signs \
stripped off) before being assigned to the reserved variable \"frame\". The \
signs are saved in the reserved variable \"signature\". Any new symbols are \
added to \"forms\", and the frame forms will be moved to the front of the \
\"forms\" list.  Existing \"drules\" are left unchanged, so any new frame \
forms (even exact ones, if new) will require them.*)"
}], "Input",
  PageBreakAbove->False,
  FontFamily->"Times"],

Cell[TextData[{
  "\n(*",
  StyleBox["Cartesian orthogonal frame",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input"],

Cell[TextData[{
  "(*The first example sets up for Euclidean 3-space using Cartesian \
coordinates and the associated natural orthogonal basis. The \"makecoords\" \
command is described fully at the end of  ",
  ButtonBox["LieDerivative_Demo.nb",
    ButtonData:>{"  LieDerivative_Demo.nb", None},
    ButtonStyle->"Hyperlink"],
  "  .*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[{x, y, z}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dscalars\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Using the argument \"dscalars\" in the next statement avoids \
introducing new basis forms, and obviates any need for \"drules\".*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeframe[dscalars]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(signature\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(scalars\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dforms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(drules\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The \"makeframe\" command implements the Hodge star operation for \
\"frame\". Mathematica 3.0 does not include an appropriate prefix operator \
for this, so it is written, hs[arg], where \"arg\" is any AVF, or list of \
AVF's. \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(vol = hs[1]\), 
    \(hs[vol]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(f = Y[depend]\), "\n", 
    \(hs[f]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(A = A1[depend] dx + A2[depend] dy + A3[depend] dz\), 
    \(hs[A]\)}], "Input",
  InitializationCell->True],

Cell["\<\
(*A co-derivative operator, \[Delta] , is also defined:  \
\[Delta][arg] = hs[hs[1]] hs[d[hs[arg]]]. No universally accepted convention \
exists for the overall sign of Hodge star operations; the use of the factor, \
hs[hs[1]] , in  \[Delta]  generally gives results consistent with \"signature\
\". *)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(df = d[f]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(delsquaredf = \[Delta][df]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(curlgradf = \[Delta][hs[df]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(divA = \[Delta][A]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(curlA = Collect[hs[d[A]], frame]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(divcurlA = \[Delta][curlA]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Note the use of da[] in the next statement which (with \
appropriate \"drules\", when necessary) ensures that the result of that \
derivative is expressed in terms of \"frame\".*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(delsquaredA = \ Collect[da[\[Delta][A]] - \[Delta][d[A]], frame]\)], 
  "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n(*",
  StyleBox["A non-Cartesian orthogonal frame",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FormatType->TextForm],

Cell["\<\
(*Except in flat space with a Cartesian frame, the orthonormal \
frame forms will have unspecified exterior derivatives which need \"drules\" \
to be expressed back in terms of \"frame\" (unless they have been selected \
from the \"dscalars\" list, as was done above). 

Furthermore, if the frame forms are not in \"dscalars\", the transformations, \
\"dcoords\"->\"frame\", must be provided in \"drules\", so that exterior \
differentiation of all frame forms and scalar functions of the coordinates \
can be accomplished using the \"da[]\" operator. All calculations are \
performed in the orthonormal frame. However, input expressions may be \
expressed in the coordinate frame, and the orthonormal output is convertible, \
as shown in the examples.

The example of spherical coordinates shows what is required.*)
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[{r, \[Theta], \[Phi]}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makeframe[{r\&^, \[Theta]\&^, \[Phi]\&^}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(signature\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(scalars\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dscalars\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dforms\)], "Input",
  InitializationCell->True],

Cell["(*Now the framedrules will be established:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(tocoords
       = {frame[\([1]\)] -> dr, frame[\([2]\)] -> r\ d\[Theta], 
        frame[\([3]\)] -> r\ Sin[\[Theta]]\ d\[Phi]}\)], "Input",
  InitializationCell->True],

Cell["(*The shortcut for this is:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(tocoords = 
      Thread[frame -> {dr, r\ d\[Theta], r\ Sin[\[Theta]]\ d\[Phi]}]\)], 
  "Input",
  InitializationCell->True],

Cell["\<\
(*The AVF command, \"prune[list , expression]\", is useful to \
select the relevant part of a longer list. In this case, it returns a list \
containing the members of \"dscalars\" that appear in \"tocoords\".*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(prunedlist = prune[dscalars, tocoords]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(toframe = 
      Flatten[Solve[\((tocoords /. Rule -> Equal)\), prunedlist]]\)], "Input",\

  InitializationCell->True],

Cell["\<\
(*The next command constructs the appropriate \"frame\" derivatives \
to be used in framedrules.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(dframe = expand[d[frame /. tocoords] /. toframe]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(framedrules = Thread[dforms -> dframe]\)], "Input",
  InitializationCell->True],

Cell["*(And now these  are established as \"drules\",*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makedrules[Join[framedrules, toframe]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Of course, it would be convenient to collect these preparation \
commands into a subroutine. Problems may arise from using Solve to get the \
inverse transformation and the possible need at times for Simplify. A better \
approach for other cases is to copy the relevant parts of this program into a \
new Notebook and modify them as necessary.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(\nvol = hs[1]\), 
    \(expand[vol /. tocoords]\)}], "Input",
  InitializationCell->True],

Cell["\<\
(*Using Hodge, an inner product, called \"dot\", can be defined for \
any two p-forms (of the same degree). For the frame forms themselves, it \
exhibits the orthonormality;*) \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(dot[\[Phi]\&^, \[Phi]\&^]\), 
    \(dot[r\&^, \[Theta]\&^]\)}], "Input",
  InitializationCell->True],

Cell["\<\
(*and for the coordinate basis it will give the covariant metric,*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mtx[
      Inverse[Table[
          dot[dscalars[\([j]\)], dscalars[\([k]\)]], {j, coordsdim}, {k, 
            coordsdim}]]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(f = Y[depend]\), 
    \(hs[f]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(df = d[f]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[f]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(divdf = \[Delta][df]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(curldf = \[Delta][hs[df]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(A = 
      A1[depend]\ r\&^ + A2[depend]\ \[Theta]\&^ + A3[depend]\ \[Phi]\&^\), 
    \(hs[A]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(B = B1[depend]\ dr + B2[depend]\ d\[Theta] + B3[depend]\ d\[Phi]\), 
    \(hs[B]\), 
    \(expand[% /. tocoords]\)}], "Input",
  InitializationCell->True],

Cell["\<\
(*The Hodge operator, hs[], also can be applied to AVF \
arrays.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(hs[{{df, A}, {B, df}}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(divA = \[Delta][A]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(curlA = Collect[hs[d[A]], frame]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(curlB = Collect[expand[hs[d[B]] /. tocoords], prunedlist]\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(divcurlA = \[Delta][curlA]\), 
    \(divcurlB = \[Delta][curlB]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(delsquaredA = Collect[da[\[Delta][A]] - \[Delta][d[A]], frame]\)], 
  "Input",
  InitializationCell->True],

Cell["\<\
(*Some inner products calculated by \"dot\", where the second and \
third demonstrate its symmetry;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(dot[B, B]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dot[A, df]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dot[df, A]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(timer[]\)], "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->None,
WindowSize->{628, 570},
WindowMargins->{{10, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@g[OK0000000000060801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 187, 5, 43, "Input"],
Cell[1944, 58, 357, 8, 76, "Input"],
Cell[2304, 68, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[2376, 72, 98, 4, 42, "Input"],
Cell[2477, 78, 929, 16, 156, "Input",
  PageBreakAbove->False],
Cell[3409, 96, 128, 5, 42, "Input"],
Cell[3540, 103, 374, 9, 60, "Input"],
Cell[3917, 114, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[4002, 118, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[4074, 122, 183, 5, 44, "Input"],
Cell[4260, 129, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[4343, 133, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[4416, 137, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[4487, 141, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[4556, 145, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[4626, 149, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[4696, 153, 278, 6, 60, "Input"],
Cell[4977, 161, 92, 3, 43, "Input",
  InitializationCell->True],
Cell[5072, 166, 98, 3, 43, "Input",
  InitializationCell->True],
Cell[5173, 171, 128, 3, 43, "Input",
  InitializationCell->True],
Cell[5304, 176, 350, 7, 60, "Input"],
Cell[5657, 185, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[5730, 189, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[5820, 193, 89, 2, 27, "Input",
  InitializationCell->True],
Cell[5912, 197, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[5994, 201, 93, 2, 27, "Input",
  InitializationCell->True],
Cell[6090, 205, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[6180, 209, 229, 5, 44, "Input"],
Cell[6412, 216, 128, 3, 27, "Input",
  InitializationCell->True],
Cell[6543, 221, 158, 6, 42, "Input"],
Cell[6704, 229, 865, 17, 204, "Input"],
Cell[7572, 248, 94, 2, 27, "Input",
  InitializationCell->True],
Cell[7669, 252, 102, 2, 32, "Input",
  InitializationCell->True],
Cell[7774, 256, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[7847, 260, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[7918, 264, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[7990, 268, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[8059, 272, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[8129, 276, 84, 1, 28, "Input"],
Cell[8216, 279, 187, 4, 27, "Input",
  InitializationCell->True],
Cell[8406, 285, 69, 1, 28, "Input"],
Cell[8478, 288, 144, 4, 27, "Input",
  InitializationCell->True],
Cell[8625, 294, 260, 6, 44, "Input"],
Cell[8888, 302, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[8990, 306, 139, 4, 27, "Input",
  InitializationCell->True],
Cell[9132, 312, 146, 4, 28, "Input"],
Cell[9281, 318, 109, 2, 27, "Input",
  InitializationCell->True],
Cell[9393, 322, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[9495, 326, 89, 1, 28, "Input"],
Cell[9587, 329, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[9689, 333, 395, 7, 76, "Input"],
Cell[10087, 342, 110, 3, 59, "Input",
  InitializationCell->True],
Cell[10200, 347, 224, 5, 44, "Input"],
Cell[10427, 354, 121, 3, 52, "Input",
  InitializationCell->True],
Cell[10551, 359, 117, 4, 28, "Input"],
Cell[10671, 365, 186, 5, 43, "Input",
  InitializationCell->True],
Cell[10860, 372, 92, 3, 43, "Input",
  InitializationCell->True],
Cell[10955, 377, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[11028, 381, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[11097, 385, 81, 2, 27, "Input",
  InitializationCell->True],
Cell[11181, 389, 86, 2, 27, "Input",
  InitializationCell->True],
Cell[11270, 393, 156, 4, 47, "Input",
  InitializationCell->True],
Cell[11429, 399, 175, 4, 59, "Input",
  InitializationCell->True],
Cell[11607, 405, 114, 4, 28, "Input"],
Cell[11724, 411, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[11810, 415, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[11892, 419, 93, 2, 27, "Input",
  InitializationCell->True],
Cell[11988, 423, 118, 2, 27, "Input",
  InitializationCell->True],
Cell[12109, 427, 126, 3, 43, "Input",
  InitializationCell->True],
Cell[12238, 432, 126, 3, 27, "Input",
  InitializationCell->True],
Cell[12367, 437, 149, 4, 28, "Input"],
Cell[12519, 443, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[12592, 447, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[12666, 451, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[12740, 455, 68, 2, 27, "Input",
  InitializationCell->True]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

